pro driver

; IDL routine
;
; driver.pro v 1.0
;
; driver.pro is the driver routine for producing an HDF file that 
;  contains individual bit flags extracted from a byte array.  This
;  particular driver has been taylored for outputing MOD06 Cloud Mask flags, 
;  but can serve as a template/example for other bit flag extractions.
;  This code assumes that the input MOD06 Cloud Mask follows the MOD06 L2QA Plan.
;
; This code produces an output HDF file, whose contents can be plotted using
;   the BitMapper code.
;
;
; Input: 
;		none
; 
; Output:
;    	none
;
; Required routines:
;    cloudmaskextracter.pro
;
; Developer
;  v 1.0   03/20/2001
;       	Eric Moody moody@climate.gsfc.nasa.gov
;           Emergent IT
;           MODIS - Atmosphere Group
;

;*************************************************************************
;Specify the year, day and time.
;Ex. for year 2000, day 95, time 4:30,
; year = '2000'
; day  = '095'
; time = '0430' 
;*************************************************************************
year = '2000'
day  = '336'
time = '0845'

;*************************************************************************
;Specify which file this is being read from, MOD06, or MOD35:
;  MODFlag = 6 for MOD06, MODFlag = 35 for MOD35.
;*************************************************************************
MODFlag = 6


;*************************************************************************
;Specify the L2QA output file name and path:
;  Note:  Specify the full path
;*************************************************************************
ClMaskHDFFileName = './output/CloudMaskTests.'+year+'.'+day+'.'+time+'.hdf'


;*************************************************************************
;Specify the path where the MOD06/35, cloud properties, file resides:
;  Note:  Specify the full path
;*************************************************************************
;MOD06 directories:
if (MODFlag eq 6) then begin
   ;MODAPS processed MOD06 directory on windhoek:
   fullpath = '/archive/MOD06/'+year+'/'+day+'/'

endif

;MOD35 paths:
if (MODFlag eq 35) then begin
   ;MODAPS processed MOD35 directory on windhoek:
   fullpath = '/archive/MOD35/'+year+'/'+day+'/'

endif



;*************************************************************************
;Find the MOD06/35 file for the specified year, day, and time
;*************************************************************************
if (MODFlag eq 6) then begin
   ;MODAPs processed files:
   file_spec = fullpath+'MOD06*'+year+day+'.'+time+'*hdf'

   result = FINDFILE(file_spec)
   MODFileName = strcompress(result[0])
endif

if (MODFlag eq 35) then begin
   ;MODAPs processed files:
   file_spec = fullpath+'MOD35*'+year+day+'.'+time+'*.hdf'

   result = FINDFILE(file_spec)
   MODFileName = strcompress(result(0))
endif



;*************************************************************************
;Specify the name of the Cloud Mask SDS:
;*************************************************************************
if (MODFlag eq 35) then begin
    ClMaskSDSName = 'Cloud_Mask'
endif 
if (MODFlag eq 6) then begin
    ClMaskSDSName = 'Cloud_Mask_1km'
endif


;*************************************************************************
;Call the code:
;*************************************************************************
cloudmaskextracter, year, day, time, MODFlag, $
                    MODFileName, ClMaskHDFFileName, ClMaskSDSName


end
