PRO l2qa_extracter, inputyear, inputday, inputtime, $
                    MOD06FileName, L2QAHDFFileName

; IDL routine
;
; l2qa_extracter.pro v 1.0
;
; l2qa_Extracter.pro will retreive individual L2 QA test results
;   from the full byte QA arrays, in the MOD06 output file.  The test results
;   are written into an output HDF file, as seperate integer SDSs.
;   This code can serve as an example/template for extracting bit flags
;   from byte arrays.
;
;
; Input: 
;    inputday		String	   : Julian Day
;    inputyear		String     : Year
;    inputtime		String	   : Time as HHMM (H=hour, M=minute)
;    MOD06FileName	String	   : The MOD06 granule filename.
;    L2QAHDFFileName	String 	   : The output L2QA filename.
; 
; Output:
;    		none
;
; Required routines:
;    ReadSDS
;    l2qa_bitextracter
;    outputl2qabits;
;
; Developer
;  v 1.0  03/20/2001
;       	Eric Moody moody@climate.gsfc.nasa.gov
;           Emergent IT
;           MODIS - Atmosphere Group
;


;*************************************************************************
;Read in the Lat Lons:
;*************************************************************************
MOD06FileID = HDF_SD_START(MOD06FileName,/READ)
LatArray = ReadSDS(MOD06FileID,'Latitude',/scaleNo,/offsetNo)
LonArray = ReadSDS(MOD06FileID,'Longitude',/scaleNo,/offsetNo)
HDF_SD_END, MOD06FileID


;*************************************************************************
;Extract the individual QA flags:
;*************************************************************************
QABitFlags = l2qa_bitextracter(MOD06FileName)


;*************************************************************************
;Output the QA flags and Lat/Lon to the HDF file:
;*************************************************************************
outputl2qabits, LatArray, LonArray,                $
                     QABitFlags, L2QAHDFFileName, $
                     inputDay, inputYear, inputTime


END